@@ -319,7 +319,9 @@ sub _deparse_seeklike {
 }
 
 sub _generate_flag_list {
-    map { my $val = eval "$_";
+    map { local $@;
+          my $val = eval "$_";
+print STDERR "*** in generate_flag_list(), $_ threw exception: $@\n" if $@;
           $val ? ( $_ => $val ) : ()
     } @_
 }
@@ -349,7 +351,7 @@ sub pp_sysopen {
     'sysopen(' . join(', ', @params) . ')';
 }
 
-my @waitpid_flags = _generate_flag_list(qw( WNOHANG WSTOPSIG WTERMSIG WUNTRACED ));
+my @waitpid_flags = _generate_flag_list(qw( WNOHANG WSTOPSIG ));
 sub pp_waitpid {
     my $self = shift;
     my $children = $self->children;
@@ -357,6 +359,7 @@ sub pp_waitpid {
                                       \@waitpid_flags);
     $flags ||= '0';
     my $target = $self->_maybe_targmy;
+print STDERR "waitpid flags: ",join(', ', @waitpid_flags),"\n";
     "${target}waitpid(" . join(', ', $children->[1]->deparse, # PID
                             $flags) . ')';
 }
